@@ -18,20 +18,7 @@ class HTTPCallback(BackendQueue):
     def __init__(self, addr: str, **kwargs):
         self.addr = addr
         self.session = None
-
-    async def stop(self):
-        while self.queue.qsize() > 0:
-            async with self.read_many_queue(self.queue.qsize()) as updates:
-                for update in updates:
-                    await self.http_write(update['data'], headers=update['headers'])
-
-        if self.session:
-            await self.session.close()
-
-    async def writer(self):
-        while True:
-            async with self.read_queue() as update:
-                await self.http_write(update['data'], headers=update['headers'])
+        self.running = True
 
     async def http_write(self, data, headers=None):
         if not self.session or self.session.closed:
