@@ -123,6 +123,8 @@ CURRENCY = 'currency'
 FUTURES = 'futures'
 PERPETUAL = 'perpetual'
 OPTION = 'option'
+OPTION_COMBO = 'option_combo'
+FUTURE_COMBO = 'future_combo'
 SPOT = 'spot'
 CALL = 'call'
 PUT = 'put'
