@@ -400,7 +400,8 @@ class FTX(Feed, FTXRestMixin):
             Decimal(order['price']) if order['price'] else None,
             Decimal(order['filledSize']),
             Decimal(order['remainingSize']),
-            None,
+            timestamp=str(order['createdAt']),
+            client_order_id=str(order['clientId']),
             account=self.subaccount,
             raw=msg
         )
